@@ -15,12 +15,21 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_ANTHY_0_3_3 $
-// $Id: platform_qpe.cpp,v 1.20 2002/07/14 15:59:04 yamaken Exp $
+// $Name: IMKIT_ANTHY_0_3_4 $
+// $Id: platform_qpe.cpp,v 1.22 2002/08/06 22:42:57 yamaken Exp $
 
 #include "platform_qpe.h"
 
 
+extern QRect qt_maxWindowRect;
+
+
+QSize
+imkit_screen_size(void) {
+  //TODO: ɸAPIǲ̥ʤĴ٤
+  return qt_maxWindowRect.size();
+}
+
 void
 QWSKeyBypassIn::on_activate(void) {
   QWSServer::setKeyboardFilter(this);
@@ -56,9 +65,7 @@ QWSKeyBypassIn::slot_activate(bool activity) {
 
 void
 QWSKeyBypassOut::on_input(QKeyEvent &e) {
-  if (is_active()) {
-    emit_as_signal(e);
-  }
+  emit_as_signal(e);
 }
 
 void
@@ -82,6 +89,14 @@ QWSKeyBypassOut::QWSKeyBypassOut(void) {
 QWSKeyBypassOut::~QWSKeyBypassOut(void) {
 }
 
+void
+QWSKeyBypassOut::input(QKeyEvent *e) {
+  if (is_active()) {
+    on_input(*e);
+  }
+  output(e);
+}
+
 void
 IMKitImpl::prepare_key_bypass(void) {
   bypass_in = new QWSKeyBypassIn;
